@@ -158,7 +158,7 @@
     type: "subsup",
     stopError: /*_()*/ ["MissingScript","Missing superscript or subscript argument"],
     supError:  /*_()*/ ["MissingOpenForSup","Missing open brace for superscript"],
-    subError:  /*_()*/ ["MissingOpenForSup","Missing open brace for subscript"],
+    subError:  /*_()*/ ["MissingOpenForSub","Missing open brace for subscript"],
     checkItem: function (item) {
       if (item.type === "open" || item.type === "left") {return true}
       if (item.type === "mml") {
@@ -186,7 +186,7 @@
         if (this.open || this.close) {
           mml.texClass = MML.TEXCLASS.INNER;
           mml.texWithDelims = true;
-          mml = TEX.mfenced(this.open,mml,this.close);
+          mml = TEX.fenced(this.open,mml,this.close);
         }
         return [STACKITEM.mml(mml), item];
       }
@@ -200,7 +200,7 @@
     stopError: /*_()*/ ["ExtraLeftMissingRight", "Extra \\left or missing \\right"],
     checkItem: function (item) {
       if (item.type === "right")
-        {return STACKITEM.mml(TEX.mfenced(this.delim,this.mmlData(),item.delim))}
+        {return STACKITEM.mml(TEX.fenced(this.delim,this.mmlData(),item.delim))}
       return this.SUPER(arguments).checkItem.call(this,item);
     }
   });
@@ -240,7 +240,7 @@
   STACKITEM.position = STACKITEM.Subclass({
     type: "position",
     checkItem: function (item) {
-      if (item.isClose) {TEX.Error(["MissingBoxFor","Missing box for %1",name])}
+      if (item.isClose) {TEX.Error(["MissingBoxFor","Missing box for %1",this.name])}
       if (item.isNotStack) {
         var mml = item.mmlData();
         switch (this.move) {
@@ -276,7 +276,7 @@
           if ((this.arraydef.columnlines||"none") != "none" ||
               (this.arraydef.rowlines||"none") != "none") {mml.padding = 0} // HTML-CSS jax implements this
         }
-        if (this.open || this.close) {mml = TEX.mfenced(this.open,mml,this.close)}
+        if (this.open || this.close) {mml = TEX.fenced(this.open,mml,this.close)}
         mml = STACKITEM.mml(mml);
         if (this.requireClose) {
           if (item.type === 'close') {return mml}
@@ -992,7 +992,7 @@
         Bmatrix:      ['Array',null,'\\{','\\}','c'],
         vmatrix:      ['Array',null,'\\vert','\\vert','c'],
         Vmatrix:      ['Array',null,'\\Vert','\\Vert','c'],
-        cases:        ['Array',null,'\\{','.','ll',null,".1em"],
+        cases:        ['Array',null,'\\{','.','ll',null,".2em",'T'],
 
         equation:     [null,'Equation'],
         'equation*':  [null,'Equation'],
@@ -1435,7 +1435,7 @@
       while (attr !== "") {
         match = attr.match(/^([a-z]+)\s*=\s*(\'[^']*'|"[^"]*"|[^ ]*)\s*/i);
         if (!match)
-          {TEX.Error("InvalidMathMLAttr","Invalid MathML attribute: %1",attr)}
+          {TEX.Error(["InvalidMathMLAttr","Invalid MathML attribute: %1",attr])}
         if (!MML[type].prototype.defaults[match[1]] && !this.MmlTokenAllow[match[1]]) {
           TEX.Error(["UnknownAttrForElement",
                      "%1 is not a recognized attribute for %2",
@@ -1757,6 +1757,7 @@
       if (open)  {array.open  = this.convertDelimiter(open)}
       if (close) {array.close = this.convertDelimiter(close)}
       if (style === "D") {array.arraydef.displaystyle = true}
+         else if (style) {array.arraydef.displaystyle = false}
       if (style === "S") {array.arraydef.scriptlevel = 1} // FIXME: should use mstyle?
       if (raggedHeight)  {array.arraydef.useHeight = false}
       this.Push(begin);
@@ -1847,7 +1848,6 @@
            case '\\':  this.i++; break;
            case '{':   parens++; break;
            case '}':
-            if (parens == 0) {TEX.Error(["ExtraClose","Extra close brace"])}
             if (--parens == 0) {return this.string.slice(j,this.i-1)}
             break;
           }
@@ -2099,7 +2099,7 @@
     formatError: function (err,math,display,script) {
       var message = err.message.replace(/\n.*/,"");
       HUB.signal.Post(["TeX Jax - parse error",message,math,display,script]);
-      return MML.merror(message);
+      return MML.Error(message);
     },
 
     //
@@ -2122,14 +2122,14 @@
     },
     
     /*
-     *  Create an mrow that represents the equivalent of an mfenced
+     *  Create an mrow that has stretchy delimiters at either end, as needed
      */
-    mfenced: function (open,mml,close) {
+    fenced: function (open,mml,close) {
       var mrow = MML.mrow();
       mrow.open = open; mrow.close = close;
-      if (open) {mrow.Append(MML.mo(open).With({fence:true, texClass:MML.TEXCLASS.OPEN}))}
+      if (open) {mrow.Append(MML.mo(open).With({fence:true, stretchy:true, texClass:MML.TEXCLASS.OPEN}))}
       if (mml.type === "mrow") {mrow.Append.apply(mrow,mml.data)} else {mrow.Append(mml)}
-      if (close) {mrow.Append(MML.mo(close).With({fence:true, texClass:MML.TEXCLASS.CLOSE}))}
+      if (close) {mrow.Append(MML.mo(close).With({fence:true, stretchy:true, texClass:MML.TEXCLASS.CLOSE}))}
       return mrow;
     },
     
